\name{china}
\docType{data}
\alias{china}
\alias{chinaMapEnv}
\title{
China Map
}
\description{
This database produces a map of China, including provincial boundaries.
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAPDATA_DATA_DIR} for the datasets in the
mapdata package) is set at package load time.
}
\seealso{
\code{\link[maps]{map}}, \code{\link[maps]{world}}
}
\examples{
map('china')
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
}
\keyword{datasets}

\eof
\name{nzHires}
\docType{data}
\alias{nzHires}
\alias{nzHiresMapEnv}
\title{
New Zealand Map
}
\description{
This database produces a high-resolution map of New Zealand.  The
database includes many Pacific Island dependencies also.
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAPDATA_DATA_DIR} for the datasets in the
mapdata package) is set at package load time.
}
\seealso{
\code{\link[maps]{map}}, \code{\link[maps]{world}}, \code{\link[maps]{nz}}
}
\examples{
map('nzHires')
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
}
\keyword{datasets}

\eof
\name{rivers}
\docType{data}
\alias{rivers}
\alias{riversMapEnv}
\title{
World Rivers Map Database
}
\description{
This database produces major rivers (and some lakes) which may be used
to add to an existing map. Unfortunately, there is no fine control over
which rivers are plotted, so all rivers which lie within the boundaries
of the current plot on display will be added.  Some of these may be
outside the boundaries of the map shown.
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAPDATA_DATA_DIR} for the datasets in the
mapdata package) is set at package load time.
}
\seealso{
\code{\link[maps]{map}}, \code{\link[maps]{world}}
}
\examples{
map('usa')
map('rivers', add=TRUE)
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
}
\keyword{datasets}

\eof
\name{world2Hires}
\docType{data}
\alias{world2Hires}
\alias{world2HiresMapEnv}
\title{
Pacific Centric World Map
}
\usage{data(world2)}
\description{
This world database comes from a cleaned-up version of the CIA
World Data Bank II data and contains approximately 2 million points
representing the world coastlines and national boundaries.  This
map is based on latitudes [0, 360), which then has the Pacific
Ocean in the centre of the map.
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAPDATA_DATA_DIR} for the datasets in the
mapdata package) is set at package load time.
}
\source{
The CIA World Data Bank II is currently (mid-2003) available from 
\url{http://www.evl.uic.edu/pape/data/WDB/}.
}
\seealso{
\code{\link[maps]{map}}, \code{\link[maps]{world}}, \code{\link{worldHires}},
\code{\link[maps]{world2}}
}
\examples{
map('world2Hires', xlim=c(100, 300))
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
}
\keyword{datasets}

\eof
\name{worldHires}
\docType{data}
\alias{worldHires}
\alias{worldHiresMapEnv}
\title{
World Map
}
\usage{data(world)}
\description{
This world database comes from a cleaned-up version of the CIA
World Data Bank II data and contains approximately 2 million points
representing the world coastlines and national boundaries.  This
makes it suitable for extracting countries, continents, etc. while
still retaining lots of detail.

The `world2' database is a modified version of the `world' database
in which the longitude ranges from 0 through 360 degrees, instead of
-180 through 180.  This then allows maps of the whole Pacific Ocean for
example.
}
\format{
The data file is merely an assignment to a character string which
specifies the name of an environment variable which contains the
base location of the binary files used by the map drawing functions.
This environment variable (\code{R_MAPDATA_DATA_DIR} for the datasets in the
mapdata package) is set at package load time.
}
\source{
The CIA World Data Bank II is currently (mid-2003) available from 
\url{http://www.evl.uic.edu/pape/data/WDB/}.
}
\seealso{
\code{\link[maps]{map}}, \code{\link[maps]{world}}
}
\examples{
map('worldHires', col=1:10)
map('worldHires', 'Switzerland')
title('Switzerland')
}
\references{
Richard A. Becker, and Allan R. Wilks,
"Maps in S",
\emph{AT\&T Bell Laboratories Statistics Research Report [93.2], 1993.}

Richard A. Becker, and Allan R. Wilks,
"Constructing a Geographical Database",
\emph{AT\&T Bell Laboratories Statistics Research Report [95.2], 1995.}
}
\keyword{datasets}

\eof
